==========
Noisy Duck
==========


.. image:: https://img.shields.io/pypi/v/noisyduck.svg
        :target: https://pypi.python.org/pypi/noisyduck

.. image:: https://img.shields.io/travis/nwukie/noisyduck.svg
        :target: https://travis-ci.org/nwukie/noisyduck

.. image:: https://readthedocs.org/projects/noisyduck/badge/?version=latest
        :target: https://noisyduck.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/nwukie/noisyduck/shield.svg
     :target: https://pyup.io/repos/github/nwukie/noisyduck/
     :alt: Updates


A python tool for computing eigenmode decompositions of duct flows.


* Free software: BSD license
* Documentation: https://noisyduck.readthedocs.io.


Features
--------

    - Annular duct mode decomposition


Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

